MethodChannelFlutterSangfor class
An implementation of FlutterSangforPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- FlutterSangforPlatform
- MethodChannelFlutterSangfor
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
connect(
{required Uri server, required String username, required String password, String? loginDomain, SangforAuthType authType = SangforAuthType.password}) → Future< SangforSession> -
override
-
disconnect(
) → Future< void> -
override
-
getCapabilities(
) → Future< SangforPlatformCapabilities> -
override
-
getState(
) → Future< SangforConnectionState> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited