FlutterSangforPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • FlutterSangforPlatform
Implementers

Constructors

FlutterSangforPlatform()
Constructs a FlutterSangforPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

connect({required Uri server, required String username, required String password, String? loginDomain, SangforAuthType authType = SangforAuthType.password}) Future<SangforSession>
disconnect() Future<void>
getCapabilities() Future<SangforPlatformCapabilities>
getState() Future<SangforConnectionState>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance FlutterSangforPlatform
The default instance of FlutterSangforPlatform to use.
getter/setter pair